@@ -1,12 +1,23 @@
+import dateutil.parser
+from datetime import timedelta
 from django import template
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.utils import simplejson
 from django.utils.html import mark_safe
+from django.utils.translation import ugettext as _
 from zumanji.helpers import get_historical_data
 
 register = template.Library()
 
+from gravatar.templatetags.gravatar import *
+
+
+@register.simple_tag
+def zumanji_version():
+    import zumanji
+    return zumanji.VERSION
+
 
 @register.filter
 def format_historical(data):
@@ -19,6 +30,16 @@ def format_historical(data):
     return ','.join(result)
 
 
+@register.filter
+def oneline(value):
+    return value.split("\n")[0]
+
+
+@register.filter
+def date_from_iso(value):
+    return dateutil.parser.parse(value)
+
+
 @register.filter('range')
 def range_filter(value):
     return range(int(value))
@@ -97,3 +118,21 @@ def render_change_row(change, compare_build):
         'columns': columns,
         'compare_build': compare_build,
     }
+
+
+@register.filter
+def timesince(value, now=None):
+    from django.template.defaultfilters import timesince
+    from django.utils import timezone
+    if now is None:
+        now = timezone.now()
+    if not value:
+        return _('never')
+    if value < (now - timedelta(days=5)):
+        return value.date()
+    value = (' '.join(timesince(value, now).split(' ')[0:2])).strip(',')
+    if value == _('0 minutes'):
+        return _('just now')
+    if value == _('1 day'):
+        return _('yesterday')
+    return value + _(' ago')
